<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

if (!class_exists('\Elementor\Widget_Base')) {
    return;
}

class Elementor_Event_Grid_Widget extends \Elementor\Widget_Base
{

    public function get_name()
    {
        return 'events-grid';
    }

    public function get_title()
    {
        return esc_html__('Events grid', 'dev-blocks');
    }

    public function get_icon()
    {
        return 'eicon-code';
    }

    public function get_categories()
    {
        return ['general'];
    }

    public function get_keywords()
    {
        return ['keyword', 'keyword'];
    }

    public function get_custom_help_url()
    {
        return 'https://go.elementor.com/widget-name';
    }

    protected function get_upsale_data()
    {
        return [];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'elementor-oembed-widget'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'mode',
            [
                'label' => esc_html__('mode', 'dev-blocks'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'future',
                'options' => [
                    '' => esc_html__('Default', 'dev-blocks'),
                    'future' => esc_html__('Future', 'dev-blocks'),
                    'Past' => esc_html__('Past', 'dev-blocks'),
                ],
            ]
        );

        // switch for limiting the number of posts
        $this->add_control(
            'limit_posts',
            [
                'label' => esc_html__('Limit posts', 'dev-blocks'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'dev-blocks'),
                'label_off' => esc_html__('No', 'dev-blocks'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        // number of posts to show if limit_posts is set to yes
        $this->add_control(
            'posts_to_show',
            [
                'label' => esc_html__('Posts to show', 'dev-blocks'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 3,
                'condition' => [
                    'limit_posts' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();
    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $mode = $settings['mode'];
        $limit_posts = $settings['limit_posts'];
        $posts_to_show = $settings['posts_to_show'];

        // I have made a new meta key called show_as_event, it is a boolean. If it is set to true, the post will be shown as an event. Include this in the query
        $meta_query = array(
            'relation' => 'AND',
            array(
                'key' => 'show_as_event',
                'value' => '1',
                'compare' => '='
            )
        );

        if ($mode === 'future') {
            $meta_query[] = array(
                'key' => 'event_end',
                'value' => date('Y-m-d H:i:s'),
                'compare' => '>',
                'type' => 'DATETIME'
            );
        } else {
            $meta_query[] = array(
                'key' => 'event_end',
                'value' => date('Y-m-d H:i:s'),
                'compare' => '<',
                'type' => 'DATETIME'
            );
        }

        $args = array(
            'post_type' => 'events',
            'posts_per_page' => $limit_posts === 'yes' ? $posts_to_show : -1,
            'order' => 'DESC',
            'orderby' => 'event_start',
            'meta_query' => $meta_query
        );

        $the_query = new WP_Query($args);

        if ($the_query->have_posts()): ?>
            <div class="event-grid">
                <?php while ($the_query->have_posts()):
                    $the_query->the_post();
                    $ticket_link = get_field('ticket_link');
                    $event_start_unformated = get_field('event_start');
                    $event_end_unformated = get_field('event_end');
                    $event_start = $event_start_unformated ? date('Y-m-d H:i:s', strtotime($event_start_unformated)) : '';
                    $event_end = date('Y-m-d H:i:s', strtotime($event_end_unformated));
                    $today = date('Y-m-d H:i:s');
                    $show_button = $ticket_link && $event_end > $today;
                    $show_body = $event_start && $event_end && $event_end > $today;
                    ?>
                    <article class="event-card">
                        <div class="event-card-image">
                            <?php the_post_thumbnail(); ?>
                        </div>

                        <div class="event-card-content">
                            <h2 class="event-card-content-title"><?php the_title(); ?></h2>
                            <?php if ($show_body) { ?>
                                <div class="event-card-content-content">
                                    <?php echo date('d.m.y H:i', strtotime($event_start)); ?>
                                </div>
                            <?php } ?>
                            <?php if ($show_button) { ?>
                                <div class="event-card-content-button-wrapper">
                                    <a href="<?php echo $ticket_link; ?>" target="_blank" rel="noopener noreferrer"
                                        class="event-card-content-link">Kjøp billetter</a>
                                </div>
                            <?php } ?>
                        </div>
                    </article>
                <?php endwhile; ?>
            </div>
        <?php endif; ?>
        <?php wp_reset_query();
    }
}